class ErrorCode:
    ok = 0

    server_error = 500

    file_already_exists = 1
    job_callback_failed = 2
    extract_archive_failed = 3
    job_timeout = 4
